@@ -4,7 +4,7 @@ import pyodbc
 import configparser
 import sqlalchemy as sa
 import urllib
-import sqlite_utilities as su
+from krazy import calculation_utilities as cu
 
 # MS Sql erver related code below _____________________________
 
@@ -127,7 +127,7 @@ def create_table(df:pd.DataFrame, table_name, conn_pyodbc:pyodbc.connect)->None:
     Creates table in MS SQL server based on dataframe supplied
     '''
 
-    df_dtypes = du.dtype_to_df(df)
+    df_dtypes = cu.dtype_to_df(df)
 
     df_dtypes['Data type'] = ''
     for ind, row in df_dtypes.iterrows():
@@ -166,7 +166,7 @@ def dbase_writer(df: pd.DataFrame, table, conn_pyodbc:pyodbc.connect, append=Tru
 
     if append=='delete_table':
         # delete table
-        su.table_delete(table_name=table, conn=conn_pyodbc)
+        table_delete(table_name=table, conn=conn_pyodbc)
         print(f'Table: {table} deleted')
 
         # create table
@@ -199,7 +199,6 @@ def dbase_writer(df: pd.DataFrame, table, conn_pyodbc:pyodbc.connect, append=Tru
     data_str = "?," * len(df.columns.tolist())
     data_str = '(' + data_str[:-1] + ')'
     sql = f'Insert into {table} {cols} values {data_str};'
-    print(sql)
 
     cur.executemany(sql, data)
     conn_pyodbc.commit()
