@@ -762,3 +762,30 @@ def pdf_page_extractor(source_path: str, dest_path: str, no_of_pages:int, auto_s
     except Exception as err:
         return [False, err]
 
+def week_to_date(year:int, week:str, day_to_extract)->datetime.date:
+    '''
+    Accepts year as integer, week as string in pattern W1, day_to_extract in pattern 0 to 6 or "all". All extracts all dates in a week and returns a list.
+    '''
+    if type(day_to_extract)==str:
+        if week[0]=='W' and week[1:].isdigit():
+            if day_to_extract=='all':
+                dates = []
+                for i in range(1,8):
+                    if i < 7:
+                        day_extracted = datetime.datetime.strptime(str(year) + '-' + week + f'-{i}', '%Y-W%W-%w')
+                        dates.append(day_extracted)
+                    elif i == 7:
+                        day_extracted = datetime.datetime.strptime(str(year) + '-' + week + '-0', '%Y-W%W-%w')
+                        dates.append(day_extracted)
+                return dates
+            else:
+                return [False, 'Invalid String']
+
+    elif type(day_to_extract)==int:
+        if 0 <= day_to_extract <= 6:
+            return datetime.datetime.strptime(str(year) + '-' + week + f'-{day_to_extract}', '%Y-W%W-%w')
+        else:
+            return [False, 'Invalid integer. It can only be between 0 to 6.']
+    
+    else:
+        return [False, 'Invalid parameter type. Either give "all" or an integer between 0 to 6.']
\ No newline at end of file
